summary refs log tree commit diff
path: root/webclient/app.js
diff options
context:
space:
mode:
Diffstat (limited to 'webclient/app.js')
-rw-r--r--webclient/app.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/webclient/app.js b/webclient/app.js
index 193c11d461..a3d1505f81 100644
--- a/webclient/app.js
+++ b/webclient/app.js
@@ -33,13 +33,13 @@ matrixWebClient.config(['$routeProvider', '$provide', '$httpProvider',
                 templateUrl: 'login/login.html',
                 controller: 'LoginController'
             }).
-            when('/room/:room_id', {
+            when('/room/:room_id_or_alias', {
                 templateUrl: 'room/room.html',
                 controller: 'RoomController'
             }).
             when('/room/', {    // room URL with room alias in it (ex: http://127.0.0.1:8000/#/room/#public:localhost:8080) will come here.
                                 // The reason is that 2nd hash key breaks routeProvider parameters cutting so that the URL will not match with 
                                 // the previous '/room/:room_id' URL rule
                 templateUrl: 'room/room.html',
                 controller: 'RoomController'
             }).
@@ -33,13 +33,13 @@ matrixWebClient.config(['$routeProvider', '$provide', '$httpProvider',
             when('/room/', {    // room URL with room alias in it (ex: http://127.0.0.1:8000/#/room/#public:localhost:8080) will come here.
                                 // The reason is that 2nd hash key breaks routeProvider parameters cutting so that the URL will not match with 
-                                // the previous '/room/:room_id' URL rule
+                                // the previous '/room/:room_id_or_alias' URL rule
                 templateUrl: 'room/room.html',
                 controller: 'RoomController'